@@ -698,6 +698,16 @@ class View extends Object {
 		return $this->Blocks->get($name, $default);
 	}
 
+/**
+ * Check if a block exists
+ *
+ * @param string $name Name of the block
+ * @return bool
+ */
+	public function exists($name) {
+		return $this->Blocks->exists($name);
+	}
+
 /**
  * End a capturing block. The compliment to View::start()
  *
